yggdrasil v2.0.7 Yggdrasil.Broker
A server to manage the subscriptions inside Yggdrasil.
Summary
Functions
Sends a request to server to counts the number of subscribers for a
channel
Sends a request to server to get the channels where the current process is
subscribed
Sends a request to server to get the channels where the process pid is
subscribed
Sends a request to server to get the subscribers of a channel
Starts the broker. Receives the generator and a :ets table monitors to
store information of the subscribers and opts a list of GenServer
options
Stops the broker server with a reason. By default reason is :normal
Sends a request to server to subscribe the current process to a channel
Sends a request to server to subscribe the process pid to a channel
Sends a request to server to unsubscribe the current process from a
channel
Sends a request to server to unsubscribe the process pid from a
channel
Functions
Sends a request to server to counts the number of subscribers for a
channel.
Sends a request to server to get the channels where the current process is
subscribed.
Sends a request to server to get the channels where the process pid is
subscribed.
Starts the broker. Receives the generator and a :ets table monitors to
store information of the subscribers and opts a list of GenServer
options.
Stops the broker server with a reason. By default reason is :normal.
Sends a request to server to subscribe the process pid to a channel.
Sends a request to server to unsubscribe the current process from a
channel.